/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.monitor.business;

import java.util.Locale;
import java.util.Set;

import com.necsoft.hinemos.webclient.bean.Property;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.exception.HinemosWebInvalidDataException;
import com.necsoft.hinemos.webclient.monitor.action.GetStatusFilterProperty;

public class GetStatusFilterPropertyBusiness {
    public Property getStatusFilterProperty(Locale locale, Set<String> managerIpSet) throws HinemosWebException {
        // 中間変数を宣言
        Property propertyStatus = null;
        // ステータス情報一覧を取得
        GetStatusFilterProperty getStatusFilterProperty = new GetStatusFilterProperty();

        propertyStatus = getStatusFilterProperty.getProperty(locale, managerIpSet);

        if (propertyStatus == null) {
            // フィルタ情報一覧の取得に失敗しました
            throw new HinemosWebInvalidDataException("exception.data.filter");
        }
        return propertyStatus;
    }
}
